# RS-Production Machine Learning
This library provides machine learning utilities.

## 1 Installation
`pip install rsp-ml`

## 2 Modules
### 2.1 rsp.ml.metrics

![](documentation/image/confusion_matrix.jpg)